@@ -1,7 +1,8 @@
 
-/*
- *  $Id$
- * Time-stamp:      "2010-02-25 15:58:39 bkorb"
+/**
+ * \file enumeration.c
+ *
+ * Time-stamp:      "2010-08-22 15:36:14 bkorb"
  *
  *   Automated Options Paged Usage module.
  *
@@ -33,27 +34,29 @@ tSCC*  pz_enum_err_fmt;
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
-enumError(
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC* const *  paz_names,
-    int           name_ct );
+enum_err(tOptions * pOpts, tOptDesc * pOD,
+         char const * const * paz_names, int name_ct);
 
 static uintptr_t
-findName(
-    tCC*          pzName,
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC* const *  paz_names,
-    unsigned int  name_ct );
+find_name(char const * pzName, tOptions * pOpts, tOptDesc * pOD,
+          char const * const *  paz_names, unsigned int name_ct);
+
+static void
+set_memb_usage(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct);
+
+static void
+set_memb_shell(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct);
+
+static void
+set_memb_names(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct);
 /* = = = END-STATIC-FORWARD = = = */
 
 static void
-enumError(
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC* const *  paz_names,
-    int           name_ct )
+enum_err(tOptions * pOpts, tOptDesc * pOD,
+         char const * const * paz_names, int name_ct)
 {
     size_t max_len = 0;
     size_t ttl_len = 0;
@@ -85,10 +88,10 @@ enumError(
      *  of all the names.
      */
     {
-        tCC * const * paz = paz_names;
+        char const * const * paz = paz_names;
 
         do  {
-            size_t len = strlen( *(paz++) ) + 1;
+            size_t len = strlen(*(paz++)) + 1;
             if (len > max_len)
                 max_len = len;
             ttl_len += len;
@@ -102,7 +105,7 @@ enumError(
      */
     if (max_len > 35) {
         do  {
-            fprintf( option_usage_fp, "  %s\n", *(paz_names++) );
+            fprintf(option_usage_fp, "  %s\n", *(paz_names++));
         } while (--ct_down > 0);
     }
 
@@ -110,12 +113,12 @@ enumError(
      *  ELSE IF they all fit on one line, then do so.
      */
     else if (ttl_len < 76) {
-        fputc( ' ', option_usage_fp );
+        fputc(' ', option_usage_fp);
         do  {
-            fputc( ' ', option_usage_fp );
-            fputs( *(paz_names++), option_usage_fp );
+            fputc(' ', option_usage_fp);
+            fputs(*(paz_names++), option_usage_fp);
         } while (--ct_down > 0);
-        fputc( '\n', option_usage_fp );
+        fputc('\n', option_usage_fp);
     }
 
     /*
@@ -125,9 +128,9 @@ enumError(
         int   ent_no = 0;
         char  zFmt[16];  /* format for all-but-last entries on a line */
 
-        sprintf( zFmt, "%%-%ds", (int)max_len );
+        sprintf(zFmt, "%%-%ds", (int)max_len);
         max_len = 78 / max_len; /* max_len is now max entries on a line */
-        fputs( "  ", option_usage_fp );
+        fputs("  ", option_usage_fp);
 
         /*
          *  Loop through all but the last entry
@@ -138,7 +141,7 @@ enumError(
                 /*
                  *  Last entry on a line.  Start next line, too.
                  */
-                fprintf( option_usage_fp, "%s\n  ", *(paz_names++) );
+                fprintf(option_usage_fp, "%s\n  ", *(paz_names++));
                 ent_no = 0;
             }
 
@@ -151,7 +154,7 @@ enumError(
     if (pOpts > OPTPROC_EMIT_LIMIT) {
         fprintf(option_usage_fp, zIntRange, hidden, name_ct - 1 + hidden);
 
-        (*(pOpts->pUsageProc))( pOpts, EXIT_FAILURE );
+        (*(pOpts->pUsageProc))(pOpts, EXIT_FAILURE);
         /* NOTREACHED */
     }
 
@@ -165,27 +168,23 @@ enumError(
 
 
 static uintptr_t
-findName(
-    tCC*          pzName,
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC* const *  paz_names,
-    unsigned int  name_ct )
+find_name(char const * pzName, tOptions * pOpts, tOptDesc * pOD,
+          char const * const *  paz_names, unsigned int name_ct)
 {
     /*
      *  Return the matching index as a pointer sized integer.
      *  The result gets stashed in a char* pointer.
      */
-    uintptr_t     res = name_ct;
-    size_t        len = strlen( (char*)pzName );
-    uintptr_t     idx;
+    uintptr_t   res = name_ct;
+    size_t      len = strlen((char*)pzName);
+    uintptr_t   idx;
 
     if (IS_DEC_DIGIT_CHAR(*pzName)) {
         char * pz = (char *)(void *)pzName;
         unsigned long val = strtoul(pz, &pz, 0);
         if ((*pz == NUL) && (val < name_ct))
             return (uintptr_t)val;
-        enumError(pOpts, pOD, paz_names, (int)name_ct);
+        enum_err(pOpts, pOD, paz_names, (int)name_ct);
         return name_ct;
     }
 
@@ -194,7 +193,7 @@ findName(
      *  Multiple partial matches means we have an ambiguous match.
      */
     for (idx = 0; idx < name_ct; idx++) {
-        if (strncmp( (char*)paz_names[idx], (char*)pzName, len) == 0) {
+        if (strncmp((char*)paz_names[idx], (char*)pzName, len) == 0) {
             if (paz_names[idx][len] == NUL)
                 return idx;  /* full match */
 
@@ -207,7 +206,7 @@ findName(
 
     pz_enum_err_fmt = (res == name_ct) ? zNoKey : zAmbigKey;
     option_usage_fp = stderr;
-    enumError(pOpts, pOD, paz_names, (int)name_ct);
+    enum_err(pOpts, pOD, paz_names, (int)name_ct);
     return name_ct;
 }
 
@@ -219,15 +218,13 @@ findName(
  * arg:   tOptDesc*,     pOD,       enumeration option description
  * arg:   unsigned int,  enum_val,  the enumeration value to map
  *
- * ret_type:  char const*
+ * ret_type:  char const *
  * ret_desc:  the enumeration name from const memory
  *
  * doc:   This converts an enumeration value into the matching string.
 =*/
-char const*
-optionKeywordName(
-    tOptDesc*     pOD,
-    unsigned int  enum_val )
+char const *
+optionKeywordName(tOptDesc * pOD, unsigned int enum_val)
 {
     tOptDesc od;
 
@@ -256,11 +253,8 @@ optionKeywordName(
  *        if there is only one partial match.
 =*/
 uintptr_t
-optionEnumerationVal(
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC * const * paz_names,
-    unsigned int  name_ct )
+optionEnumerationVal(tOptions * pOpts, tOptDesc * pOD,
+                     char const * const * paz_names, unsigned int name_ct)
 {
     uintptr_t res = 0UL;
 
@@ -273,7 +267,7 @@ optionEnumerationVal(
         /*
          *  print the list of enumeration names.
          */
-        enumError(pOpts, pOD, paz_names, (int)name_ct);
+        enum_err(pOpts, pOD, paz_names, (int)name_ct);
         break;
 
     case (uintptr_t)OPTPROC_EMIT_SHELL:
@@ -283,9 +277,9 @@ optionEnumerationVal(
          *  print the name string.
          */
         if (ix >= name_ct)
-            printf( "INVALID-%d", ix );
+            printf("INVALID-%d", ix);
         else
-            fputs( paz_names[ ix ], stdout );
+            fputs(paz_names[ ix ], stdout);
 
         break;
     }
@@ -305,7 +299,7 @@ optionEnumerationVal(
     }
 
     default:
-        res = findName(pOD->optArg.argString, pOpts, pOD, paz_names, name_ct);
+        res = find_name(pOD->optArg.argString, pOpts, pOD, paz_names, name_ct);
 
         if (pOD->fOptState & OPTST_ALLOC_ARG) {
             AGFREE(pOD->optArg.argString);
@@ -317,6 +311,84 @@ optionEnumerationVal(
     return res;
 }
 
+static void
+set_memb_usage(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct)
+{
+    /*
+     *  print the list of enumeration names.
+     */
+    enum_err(OPTPROC_EMIT_USAGE, pOD, paz_names, (int)name_ct );
+}
+
+static void
+set_memb_shell(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct)
+{
+    /*
+     *  print the name string.
+     */
+    int       ix   =  0;
+    uintptr_t bits = (uintptr_t)pOD->optCookie;
+    size_t    len  = 0;
+
+    bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
+
+    while (bits != 0) {
+        if (bits & 1) {
+            if (len++ > 0) fputs(" | ", stdout);
+            fputs(paz_names[ix], stdout);
+        }
+        if (++ix >= name_ct) break;
+        bits >>= 1;
+    }
+}
+
+static void
+set_memb_names(tOptions * pOpts, tOptDesc * pOD, char const * const * paz_names,
+               unsigned int name_ct)
+{
+    char*     pz;
+    uintptr_t bits = (uintptr_t)pOD->optCookie;
+    int       ix   = 0;
+    size_t    len  = 5;
+
+    bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
+
+    /*
+     *  Replace the enumeration value with the name string.
+     *  First, determine the needed length, then allocate and fill in.
+     */
+    while (bits != 0) {
+        if (bits & 1)
+            len += strlen(paz_names[ix]) + 8;
+        if (++ix >= name_ct) break;
+        bits >>= 1;
+    }
+
+    pOD->optArg.argString = pz = AGALOC(len, "enum name");
+
+    /*
+     *  Start by clearing all the bits.  We want to turn off any defaults
+     *  because we will be restoring to current state, not adding to
+     *  the default set of bits.
+     */
+    strcpy(pz, "none");
+    pz += 4;
+    bits = (uintptr_t)pOD->optCookie;
+    bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
+    ix = 0;
+
+    while (bits != 0) {
+        if (bits & 1) {
+            strcpy(pz, " + ");
+            strcpy(pz+3, paz_names[ix]);
+            pz += strlen(paz_names[ix]) + 3;
+        }
+        if (++ix >= name_ct) break;
+        bits >>= 1;
+    }
+}
 
 /*=export_func  optionSetMembers
  * what:  Convert between bit flag values and strings
@@ -335,11 +407,8 @@ optionEnumerationVal(
  *        if there is only one partial match.
 =*/
 void
-optionSetMembers(
-    tOptions*     pOpts,
-    tOptDesc*     pOD,
-    tCC* const *  paz_names,
-    unsigned int  name_ct )
+optionSetMembers(tOptions * pOpts, tOptDesc * pOD,
+                 char const* const * paz_names, unsigned int name_ct)
 {
     /*
      *  IF the program option descriptor pointer is invalid,
@@ -347,78 +416,16 @@ optionSetMembers(
      */
     switch ((uintptr_t)pOpts) {
     case (uintptr_t)OPTPROC_EMIT_USAGE:
-        /*
-         *  print the list of enumeration names.
-         */
-        enumError(OPTPROC_EMIT_USAGE, pOD, paz_names, (int)name_ct );
+        set_memb_usage(pOpts, pOD, paz_names, name_ct);
         return;
 
     case (uintptr_t)OPTPROC_EMIT_SHELL:
-    {
-        /*
-         *  print the name string.
-         */
-        int       ix   =  0;
-        uintptr_t bits = (uintptr_t)pOD->optCookie;
-        size_t    len  = 0;
-
-        bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
-
-        while (bits != 0) {
-            if (bits & 1) {
-                if (len++ > 0) fputs( " | ", stdout );
-                fputs(paz_names[ix], stdout);
-            }
-            if (++ix >= name_ct) break;
-            bits >>= 1;
-        }
+        set_memb_shell(pOpts, pOD, paz_names, name_ct);
         return;
-    }
 
     case (uintptr_t)OPTPROC_RETURN_VALNAME:
-    {
-        char*     pz;
-        uintptr_t bits = (uintptr_t)pOD->optCookie;
-        int       ix   = 0;
-        size_t    len  = 5;
-
-        bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
-
-        /*
-         *  Replace the enumeration value with the name string.
-         *  First, determine the needed length, then allocate and fill in.
-         */
-        while (bits != 0) {
-            if (bits & 1)
-                len += strlen( paz_names[ix]) + 8;
-            if (++ix >= name_ct) break;
-            bits >>= 1;
-        }
-
-        pOD->optArg.argString = pz = AGALOC(len, "enum name");
-
-        /*
-         *  Start by clearing all the bits.  We want to turn off any defaults
-         *  because we will be restoring to current state, not adding to
-         *  the default set of bits.
-         */
-        strcpy( pz, "none" );
-        pz += 4;
-        bits = (uintptr_t)pOD->optCookie;
-        bits &= ((uintptr_t)1 << (uintptr_t)name_ct) - (uintptr_t)1;
-        ix = 0;
-
-        while (bits != 0) {
-            if (bits & 1) {
-                strcpy( pz, " + " );
-                strcpy( pz+3, paz_names[ix]);
-                pz += strlen( paz_names[ix]) + 3;
-            }
-            if (++ix >= name_ct) break;
-            bits >>= 1;
-        }
+        set_memb_names(pOpts, pOD, paz_names, name_ct);
         return;
-    }
 
     default:
         break;
@@ -428,7 +435,7 @@ optionSetMembers(
         return;
 
     {
-        tCC*      pzArg = pOD->optArg.argString;
+        char const*      pzArg = pOD->optArg.argString;
         uintptr_t res;
         if ((pzArg == NULL) || (*pzArg == NUL)) {
             pOD->optCookie = (void*)0;
@@ -440,44 +447,44 @@ optionSetMembers(
             tSCC zSpn[] = " ,|+\t\r\f\n";
             int  iv, len;
 
-            pzArg += strspn( pzArg, zSpn );
+            pzArg += strspn(pzArg, zSpn);
             iv = (*pzArg == '!');
             if (iv)
-                pzArg += strspn( pzArg+1, zSpn ) + 1;
+                pzArg += strspn(pzArg+1, zSpn) + 1;
 
-            len = strcspn( pzArg, zSpn );
+            len = strcspn(pzArg, zSpn);
             if (len == 0)
                 break;
 
-            if ((len == 3) && (strncmp(pzArg, zAll, (size_t)3) == 0)) {
+            if ((len == 3) && (strncmp(pzArg, zAll, 3) == 0)) {
                 if (iv)
                      res = 0;
                 else res = ~0UL;
             }
-            else if ((len == 4) && (strncmp(pzArg, zNone, (size_t)4) == 0)) {
+            else if ((len == 4) && (strncmp(pzArg, zNone, 4) == 0)) {
                 if (! iv)
                     res = 0;
             }
             else do {
                 char* pz;
-                uintptr_t bit = strtoul( pzArg, &pz, 0 );
+                uintptr_t bit = strtoul(pzArg, &pz, 0);
 
                 if (pz != pzArg + len) {
                     char z[ AO_NAME_SIZE ];
-                    tCC* p;
+                    char const* p;
                     int  shift_ct;
 
                     if (*pz != NUL) {
                         if (len >= AO_NAME_LIMIT)
                             break;
-                        strncpy( z, pzArg, (size_t)len );
+                        strncpy(z, pzArg, (size_t)len);
                         z[len] = NUL;
                         p = z;
                     } else {
                         p = pzArg;
                     }
 
-                    shift_ct = findName(p, pOpts, pOD, paz_names, name_ct);
+                    shift_ct = find_name(p, pOpts, pOD, paz_names, name_ct);
                     if (shift_ct >= name_ct) {
                         pOD->optCookie = (void*)0;
                         return;
@@ -493,7 +500,7 @@ optionSetMembers(
                 break;
             pzArg += len + 1;
         }
-        if (name_ct < (8 * sizeof( uintptr_t ))) {
+        if (name_ct < (8 * sizeof(uintptr_t))) {
             res &= (1UL << name_ct) - 1UL;
         }
 
